#!/bin/sh
### BEGIN INIT INFO
# Provides:          utserver-daemon
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the utserver-daemon.
### END INIT INFO

PKG_NAME="utorrent"
PKG_DIR="/usr/local/AppCentral/utorrent"
RUN_AS="admin:administrators"
CONFIG_DIR="$PKG_DIR/config"
DOWNLOAD_DIR=$(/bin/sed -n "/^\[Download\]/,/^\[.*\]/s/^path[ \t]*=[ \t]*\(.*$\)/\1/p" /volume0/usr/builtin/etc/samba/smb.conf)
LOG_FILE="$DOWNLOAD_DIR/utorrent/log/utlog.log" #WARN: actual logfile location is read during start command
PID_FILE="$PKG_DIR/$PKG_NAME.pid"
DAEMON="/usr/local/bin/utserver"
DAEMON_PACKAGE="" #change according to daemon version used
DAEMON_OPTS=" -settingspath $CONFIG_DIR -logfile $LOG_FILE -configfile $CONFIG_DIR/utserver.conf -pidfile $PID_FILE -daemon"
REPOS_DIR="$PKG_DIR/repository"
umask 0 

#crude fix as the PATH variable isn't properly setup yet on boottime
export PATH="${PATH:+$PATH:}/usr/local/bin"
export LD_LIBRARY_PATH="/usr/local/lib"
export LANG=en_US.UTF-8

CreateLinks() { #links some libraries	
	#Create symbolic links for required binary utils and library files
	/bin/echo -n " Creating Symbolic links for required utils"
	[ -f /usr/local/bin/utserver ] || /bin/ln -sf "${REPOS_DIR}/bin/utserver" "/usr/local/bin/utserver"
	[ -f /usr/local/lib/libcrypto.so.0.9.8 ] || /bin/ln -sf "${REPOS_DIR}/lib/libcrypto.so.0.9.8" "/usr/local/lib/libcrypto.so.0.9.8"
	[ -f /usr/local/lib/libssl.so.0.9.8 ] || /bin/ln -sf "${REPOS_DIR}/lib/libssl.so.0.9.8" "/usr/local/lib/libssl.so.0.9.8"
	[ -f /usr/builtin/etc/nginx/sites-enabled/uTorrent-ssl.conf ] || /bin/ln -sf "${CONFIG_DIR}/uTorrent-ssl.conf" "/usr/builtin/etc/nginx/sites-enabled/uTorrent-ssl.conf"  
	/bin/echo -n "..."
	/bin/echo " Done"
}

case "$1" in
  start)
	/bin/echo "Starting PKG_NAME... "
	[ -d ${DOWNLOAD_DIR}/utorrent ] || /bin/mkdir ${DOWNLOAD_DIR}/utorrent
	[ -d ${DOWNLOAD_DIR}/utorrent/log ] || /bin/mkdir ${DOWNLOAD_DIR}/utorrent/log
	/bin/chown -R $RUN_AS $DOWNLOAD_DIR/utorrent
	/bin/chmod -R -t $DOWNLOAD_DIR/utorrent # make sure no system bits are set.
	/bin/chmod -R -s $DOWNLOAD_DIR/utorrent # make sure no system bits are set.
	#ensure all necessary links are enabled.
	CreateLinks

	#Restart nginx with uTorrent-ssl enabled.
	/usr/builtin/sbin/nginx -s reload

       #chmod
	/bin/chmod 777 $DAEMON
	/bin/chown -R $RUN_AS $PKG_DIR

	/bin/echo "Starting utserver daemon... "
	/sbin/start-stop-daemon -S -p $PID_FILE -c $RUN_AS -x ${DAEMON} --${DAEMON_OPTS}
	RETVAL=$?
  ;;
	
  stop)
	/bin/echo "Shutting down $PKG_NAME... "
	#$DAEMON --quit
	/bin/sleep 1
	/bin/pidof utserver 1>>/dev/null 2>>/dev/null
	if [ $? = 0 ]; then
		/usr/bin/killall utserver
		RETVAL=$?
	fi
	/bin/sleep 1
	RETVAL=$?
	/bin/sleep 3
  ;;
		
  restart)
	$0 stop
	/bin/sleep 10
	$0 start
	RETVAL=$?
  ;;
  *)
	/bin/echo "Usage: $0 {start|stop|restart}"
esac

exit 0
